uvm-python
==========

`uvm-python <https://github.com/tpoikela/uvm-python>`_ is a port of the
`Universal Verification Methodology (UVM) <https://www.accellera.org/downloads/standards/uvm>`_
version 1.2 to `Python <https://python.org>`_ and the 
`cocotb Coroutine based Cosimulation Testbench environment <https://cocotb.readthedocs.io/>`_.

.. toctree::
   :maxdepth: 2

   uvm_1.2_class_reference
   uvm_users_guide_1.2


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
